//
// XMM Science Analysis System
//
// Giuseppe Vacanti (cosine) 
// October 2000
//
#ifndef EPPROC_H
#define EPPROC_H

#include <Xmm.h>
#include <Odf.h>
#include <ParameterInfo.h>


#include <Proc.h>

#include <vector>
#include <string>

class Epproc {
public:
  Epproc();
  ~Epproc();

  void selectDataModes();
  void selectCcds();
  void selectExposures();
  void processAttitude();
  void processHk();

  void mergeGtis();

  unsigned numberOfExposures() const;
  void processExposure(unsigned&);
  void combineEventLists(const vector<string>& el,
			 const Proc::ScienceExposure& exp,
			 const bool& filtered = false);

  typedef list<const OdfSet*>::const_iterator LI;

private:

  void cleanup();

  ParameterInfo& _mypars;
  const XmmInstrument& _inst;

  vector<Xmm::DataMode> _datamodes;
  vector<Ccd> _ccds;
  vector<Proc::ScienceExposure> _exposures;
  vector<string> _gtis; // applicable at the observation level
  bool _hasfilterexpression;
  string _filterexpression; // applicable to all exposures
  string _post_selection_expression; // applicable to the combined (filtered) event list
  bool _hasatthkgenset;
  bool _hasobservationlevelgti;
  bool _hashkgti;
  Proc _proc;

};

#endif
